'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _cleanReactProps = require('clean-react-props');

var _cleanReactProps2 = _interopRequireDefault(_cleanReactProps);

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

require('jquery.ripples');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var useTarget = function useTarget(_ref) {
  var imageUrl = _ref.imageUrl,
      dropRadius = _ref.dropRadius,
      perturbance = _ref.perturbance,
      resolution = _ref.resolution,
      interactive = _ref.interactive,
      crossOrigin = _ref.crossOrigin,
      rippleRef = _ref.rippleRef;

  var target = (0, _react.useRef)({ ripples: function ripples() {} });

  (0, _react.useEffect)(function () {
    target.current = (0, _jquery2.default)(rippleRef.current);

    target.current.ripples({
      imageUrl: imageUrl,
      dropRadius: dropRadius,
      perturbance: perturbance,
      resolution: resolution,
      interactive: interactive,
      crossOrigin: crossOrigin
    });

    return function () {
      return target.current.ripples('destroy');
    };
  }, []);

  var destroy = target.current.ripples('destroy');

  var drop = function drop() {
    var _ref2 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
      x: undefined,
      y: undefined,
      radius: undefined,
      strength: undefined
    },
        _ref2$x = _ref2.x,
        x = _ref2$x === undefined ? undefined : _ref2$x,
        _ref2$y = _ref2.y,
        y = _ref2$y === undefined ? undefined : _ref2$y,
        _ref2$radius = _ref2.radius,
        radius = _ref2$radius === undefined ? undefined : _ref2$radius,
        _ref2$strength = _ref2.strength,
        strength = _ref2$strength === undefined ? undefined : _ref2$strength;

    target.current.ripples('drop', x, y, radius, strength);
  };

  var pause = function pause() {
    target.current.ripples('pause');
  };

  var play = function play() {
    target.current.ripples('play');
  };

  var hide = function hide() {
    target.current.ripples('hide');
  };

  var show = function show() {
    target.current.ripples('show');
  };

  var set = function set() {
    var _ref3 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
      property: undefined,
      value: undefined
    },
        _ref3$property = _ref3.property,
        property = _ref3$property === undefined ? undefined : _ref3$property,
        _ref3$value = _ref3.value,
        value = _ref3$value === undefined ? undefined : _ref3$value;

    target.current.ripples('set', property, value);
  };

  var updateSize = function updateSize() {
    target.current.ripples('updateSize');
  };

  return {
    destroy: destroy,
    pause: pause,
    play: play,
    hide: hide,
    show: show,
    drop: drop,
    set: set,
    updateSize: updateSize
  };
};

var WaterEffect = function WaterEffect(_ref4) {
  var imageUrl = _ref4.imageUrl,
      dropRadius = _ref4.dropRadius,
      perturbance = _ref4.perturbance,
      resolution = _ref4.resolution,
      interactive = _ref4.interactive,
      crossOrigin = _ref4.crossOrigin,
      children = _ref4.children,
      otherProps = _objectWithoutProperties(_ref4, ['imageUrl', 'dropRadius', 'perturbance', 'resolution', 'interactive', 'crossOrigin', 'children']);

  var rippleRef = (0, _react.useRef)();

  var _useTarget = useTarget({
    imageUrl: imageUrl,
    dropRadius: dropRadius,
    perturbance: perturbance,
    resolution: resolution,
    interactive: interactive,
    crossOrigin: crossOrigin,
    rippleRef: rippleRef
  }),
      destroy = _useTarget.destroy,
      pause = _useTarget.pause,
      play = _useTarget.play,
      hide = _useTarget.hide,
      show = _useTarget.show,
      drop = _useTarget.drop,
      set = _useTarget.set,
      updateSize = _useTarget.updateSize;

  return _react2.default.createElement(
    'div',
    _extends({ ref: rippleRef }, (0, _cleanReactProps2.default)(otherProps)),
    children({
      destroy: destroy,
      pause: pause,
      play: play,
      hide: hide,
      show: show,
      drop: drop,
      set: set,
      updateSize: updateSize
    })
  );
};

WaterEffect.propTypes = process.env.NODE_ENV !== "production" ? {
  imageUrl: _propTypes2.default.string,
  dropRadius: _propTypes2.default.number,
  perturbance: _propTypes2.default.number,
  resolution: _propTypes2.default.number,
  interactive: _propTypes2.default.bool,
  crossOrigin: _propTypes2.default.string,
  children: _propTypes2.default.func
} : {};

WaterEffect.defaultProps = {
  imageUrl: null,
  dropRadius: 20,
  perturbance: 0.03,
  resolution: 256,
  interactive: true,
  crossOrigin: '',
  children: function children() {}
};

exports.default = WaterEffect;
module.exports = exports['default'];